bayespy.nodes.GaussianGammaARD.get_riemannian_gradient
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaARD.get_riemannian_gradient